SystemOrganization addCategory: #'Xpf-Client-Tests'!
SystemOrganization addCategory: #'Xpf-Client-Morphs'!
SystemOrganization addCategory: #'Xpf-Client-Helpers'!

PluggableDialogWindow subclass: #XpfUserStoryDetailWindow
	instanceVariableNames: 'explanationText titleText'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfUserStoryDetailWindow class methodsFor: 'instance creation' stamp: 'mt 2/26/2009 16:47'!
newFor: aUserStory

	^ self new initializeWith: aUserStory! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 2/26/2009 17:09'!
createExplanationTextFor: aUserStory

	explanationText := UITheme current
		newTextEditorIn: self
		for: aUserStory
		getText: #explanation
		setText: #explanation:
		getEnabled: nil.
	^ explanationText! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 2/26/2009 17:04'!
createLabel

	^ UITheme current
		newLabelIn: self
		label: 'Title:'.! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 2/26/2009 17:10'!
createTitleTextFor: aUserStory

	titleText := (UITheme current
		newTextEntryIn: self
		for: aUserStory
		get: #title
		set: #title:
		class: String
		getEnabled: nil
		help: 'Enter a short descriptive title for this user story.') maxLength: 100.
	^ titleText! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 2/26/2009 17:10'!
explanationText
	^ explanationText! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 2/26/2009 17:10'!
explanationText: anObject
	explanationText := anObject! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 2/26/2009 17:39'!
initializeWith: aUserStory

	| col row |	
	row := UITheme current newRowIn: self for: {
		self createLabel.
		self createTitleTextFor: aUserStory}.
		
	col := UITheme current newColumnIn: self for: {
		row.
		self createExplanationTextFor: aUserStory}.
		
	self
		contentMorph: col;
		model: aUserStory;
		addGrips;
		title: aUserStory title.! !

!XpfUserStoryDetailWindow methodsFor: 'actions' stamp: 'mt 2/26/2009 18:17'!
ok

	self titleText accept.
	self explanationText accept.
	
	super ok.! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 2/26/2009 17:10'!
titleText
	^ titleText! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 2/26/2009 17:10'!
titleText: anObject
	titleText := anObject! !

TestCase subclass: #XpfClientTest
	instanceVariableNames: 'project userstory1 userstory2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfClientTest methodsFor: 'running' stamp: 'mt 2/26/2009 16:59'!
setUp
	super setUp.
	project := XpfProject new title: 'Test Project'.
	userstory1 := XpfUserStory new title: 'Test User Story with long title.'; explanation: 'This is the explanantion of a user story.'.
	userstory2 := XpfUserStory new title: 'Test User Story'.
	project
		addUserStory: userstory1;
		addUserStory: userstory2.! !

!XpfClientTest methodsFor: 'running' stamp: 'cs 2/23/2009 15:50'!
tearDown
	project
		removeUserStory: userstory1;
		removeUserStory: userstory1! !

!XpfClientTest methodsFor: 'tests' stamp: 'SR 2/23/2009 11:19'!
testAddUSMorphsToProjectMorph

	| sut usMorphCount |
	sut := XpfProjectMorph new.
	usMorphCount := sut userStorySubmorphs size.
	
	sut addUserStoryMorph: (XpfUserStoryMorph newFor: userstory1).
	self should: sut userStorySubmorphs size = (usMorphCount + 1).! !

!XpfClientTest methodsFor: 'tests' stamp: 'SR 2/23/2009 12:18'!
testProjectTitleDisplay

	| sut |
	sut := XpfClient newFor: project.
	
 	self should: sut label = project printString.! !

!XpfClientTest methodsFor: 'tests' stamp: 'mt 2/26/2009 17:11'!
testUserStoryDetailWindow

	| sut |
	sut := XpfUserStoryDetailWindow newFor: userstory1.

	self
		should: sut titleText getText = userstory1 title
		description: 'The text entry should contain the title of the user story.'.
		
	self
		should: sut explanationText getText = userstory1 explanation
		description: 'The explanation is not correct'.! !

!XpfClientTest methodsFor: 'tests' stamp: 'mt 2/26/2009 17:30'!
testUserStoryDetailWindowOk

	| sut newTitle newExp |
	sut := XpfUserStoryDetailWindow newFor: userstory1.
	
	newTitle := 'Changed Text.'.
	newExp := 'Changed Explanation.'.

	sut titleText textMorph contents: newTitle.
	sut explanationText textMorph contents: newExp.
	
	self
		shouldnt: userstory1 title = newTitle;
		shouldnt: userstory1 explanation = newExp.
			
	sut ok.
	
	self
		should: userstory1 title = newTitle;
		should: userstory1 explanation = newExp.! !

!XpfClientTest methodsFor: 'tests' stamp: 'SR 2/23/2009 10:54'!
testUserStorySubmorphs

	| sut |
	sut := XpfProjectMorph newFor: project.
	
	
	self 
		should: sut userStorySubmorphs size = project userStories size.
		
	sut userStorySubmorphs do: [ :usMorph| 
		self should: (project userStories includes: usMorph model)].! !

!XpfClientTest methodsFor: 'tests' stamp: 'cs 2/23/2009 15:29'!
testUserStoryTextContent
	| sut titleMorph |
	sut := XpfUserStoryMorph newFor: userstory1.
	self should: sut submorphCount > 0.
	
	titleMorph := sut submorphs detect: [:submorph |
			submorph isTextMorph and: [submorph text asString = userstory1 printString]].
	self
		shouldnt: titleMorph isNil;
		should: (titleMorph wrapString startsWith: '<yes>');
	 	should: titleMorph width <= 100.! !

!Morph methodsFor: '*xpf-client' stamp: 'SR 2/23/2009 10:49'!
isUserStoryMorph
	^ false! !

Morph subclass: #XpfUserStoryMorph
	instanceVariableNames: 'model titleMorph enabled'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfUserStoryMorph class methodsFor: 'defaults' stamp: 'cs 2/23/2009 15:08'!
defaultColor
	^ Color lightOrange! !

!XpfUserStoryMorph class methodsFor: 'defaults' stamp: 'cs 2/23/2009 15:08'!
defaultExtent
	^ 100@60 ! !

!XpfUserStoryMorph class methodsFor: 'initialize-release' stamp: 'cs 2/26/2009 11:26'!
newFor: anXpfUserStory

	^ self new
		model: anXpfUserStory! !

!XpfUserStoryMorph methodsFor: 'event handling' stamp: 'mt 2/26/2009 18:09'!
doubleClick: evt

	self enabled: false.
	(XpfUserStoryDetailWindow newFor: self model) openInHand.! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'mt 2/26/2009 18:07'!
enabled

	^ enabled! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'mt 2/26/2009 18:07'!
enabled: aBoolean

	enabled := aBoolean! !

!XpfUserStoryMorph methodsFor: 'event handling' stamp: 'mt 2/26/2009 18:10'!
handlesMouseDown: evt

	self enabled ifTrue:
		[evt hand waitForClicksOrDrag: self event: evt].

	^ self enabled not! !

!XpfUserStoryMorph methodsFor: 'initialization' stamp: 'mt 2/26/2009 18:10'!
initialize

	super initialize.
	self
		extent: self class defaultExtent;
		titleMorph: TextMorph new lock;
		borderWidth: 2;
		borderColor: Color brown;
		color: self class defaultColor;
		enabled: true.! !

!XpfUserStoryMorph methodsFor: 'testing' stamp: 'SR 2/23/2009 10:49'!
isUserStoryMorph
	^ true! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'SR 2/23/2009 10:56'!
model
	^ model! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'cs 2/23/2009 14:58'!
model: anObject
	model := anObject.
	self update.! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'cs 2/26/2009 11:26'!
titleMorph
	^ titleMorph! !

!XpfUserStoryMorph methodsFor: 'accessing' stamp: 'cs 2/26/2009 11:52'!
titleMorph: anObject
	titleMorph ifNotNil: [self removeMorph: titleMorph].
	titleMorph := anObject.
	self addMorph: titleMorph.
	titleMorph topLeft: 4@2! !

!XpfUserStoryMorph methodsFor: 'updating' stamp: 'cs 2/26/2009 11:40'!
update

	self titleMorph
		contents: self model printString;
		wrapFlag: true;
		extent: 100@60.! !

PluggableSystemWindow subclass: #XpfClient
	instanceVariableNames: 'projectMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfClient class methodsFor: 'as yet unclassified' stamp: 'topa 2/24/2009 19:54'!
newFor: anXpfProject
	^ self new
		model: anXpfProject;
		getLabelSelector: #printString.! !

!XpfClient methodsFor: 'initialization' stamp: 'topa 2/24/2009 19:25'!
initialize
	super initialize.
	
	self 
		projectMorph: XpfProjectMorph new;
		addMorph: self projectMorph 
		 fullFrame: (LayoutFrame fractions: (0@0 corner: 1@1) offsets: (0@0 corner: 0@0)).! !

!XpfClient methodsFor: 'accessing' stamp: 'topa 2/24/2009 19:51'!
model: anXpfProject
	super model: anXpfProject.
	self projectMorph model: anXpfProject.! !

!XpfClient methodsFor: 'accessing' stamp: 'SR 2/23/2009 12:08'!
projectMorph
	^ projectMorph! !

!XpfClient methodsFor: 'accessing' stamp: 'SR 2/23/2009 12:08'!
projectMorph: anObject
	projectMorph := anObject! !

PasteUpMorph subclass: #XpfProjectMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfProjectMorph class methodsFor: 'initialize-release' stamp: 'SR 2/23/2009 12:11'!
newFor: anXpfProject

	^ self new
		model: anXpfProject! !

!XpfProjectMorph methodsFor: 'accessing' stamp: 'SR 2/23/2009 11:19'!
addUserStoryMorph: anXpfUserStoryMorph

	^ self addMorph: anXpfUserStoryMorph! !

!XpfProjectMorph methodsFor: 'initialization' stamp: 'SR 2/23/2009 11:19'!
buildUserStorySubmorphs

	self model userStories do: [ :userStory| 
		self addUserStoryMorph: (XpfUserStoryMorph newFor: userStory)]! !

!XpfProjectMorph methodsFor: 'as yet unclassified' stamp: 'topa 2/24/2009 19:35'!
initialize
	super initialize.
	self acquireBorderWidth: 5.! !

!XpfProjectMorph methodsFor: 'accessing' stamp: 'SR 2/23/2009 12:14'!
model: anObject

	self removeAllMorphsIn: self userStorySubmorphs. 
	model := anObject.
	self buildUserStorySubmorphs.
! !

!XpfProjectMorph methodsFor: 'accessing' stamp: 'SR 2/23/2009 10:51'!
userStorySubmorphs

	^ self allMorphs select: [:aMorph| aMorph isUserStoryMorph]! !
